spacepy.datamodel.fromCDF — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »

# spacepy.datamodel.fromCDF

`spacepy.datamodel.` `fromCDF`(fname, **kwargs)

  Create a SpacePy datamodel representation of a NASA CDF file

  Parameters: | file : string the name of the cdf file to be loaded into a datamodel
  Returns: | out : spacepy.datamodel.SpaceData SpaceData with associated attributes and variables in dmarrays

  See also

  `spacepy.pycdf.CDF.copy`

  Examples

      >>> import spacepy.datamodel as dm
      >>> data = dm.fromCDF('test.cdf')

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »